@@ -8,10 +8,14 @@ from .widgets import SirTrevorWidget
 from .render import render_json
 
 
+def default():
+    return {'data': []}
+
+
 class SirTrevorField(JSONField):
 
     def __init__(self, blocks=None, **kwargs):
-        kwargs.setdefault('default', lambda: {'data': []})
+        kwargs.setdefault('default', default)
         super(SirTrevorField, self).__init__(**kwargs)
         self.blocks = blocks
 
