@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function, unicode_literals
+
 import json
 
 from django.forms import widgets
@@ -24,10 +26,12 @@ class SirTrevorWidget(widgets.Textarea):
         return media
 
     def render(self, name, value, attrs=None):
+        if isinstance(value, (dict, list)):
+            value = json.dumps(value)
+
         final_attrs = self.build_attrs(attrs, name=name)
         textarea = format_html('<textarea{0}>{1}</textarea>',
-                               flatatt(final_attrs),
-                               json.dumps((value)))
+                               flatatt(final_attrs), value)
 
         id_ = final_attrs.get('id', None)
         if id_ is None:
